@@ -27,27 +27,27 @@ import string
 
 class ProgramHandler():
     button_dictionary= { \
-        "power":"^power|^on_off|^esc|^halt", \
+        "power":"^power|^on_off|^esc|^halt|^off", \
         "up":"^up|^arrow_up|^up_arrow|^arrowup", \
         "down":"^down|^down_arrow|^arrow_down|^arrowdown", \
         "left":"^left|^leftarrow|^seek\-|^right_arrow_term|^arrow_left|^arrowleft|^skipback", \
         "right":"^right|^rightarrow|^seek\+|^left_arrow_term|^arrow_right|^arrowright|^skipfwd", \
         "enter":"^enter|^ent|^start", \
-        "rewind":"^rewind|^fastrwd|^rev|^backward|^rrev|^rwnd|^rrew|^grew", \
-        "forward":"^forward|^fastfwd|^fwd|^fforward|^ffwd|^ff|^rff|^gff|^ffw|^fwdwind", \
+        "rewind":"^rewind|^fastrwd|^rev|^backward|^rrev|^rwnd|^rrew|^grew|^skipr|^skipprior", \
+        "forward":"^forward|^fastfwd|^fwd|^fforward|^ffwd|^ff|^rff|^gff|^ffw|^fwdwind|^jump|^skipf|^skipnext|^fastforward", \
         "vol-":"^vol\-|^voldown|^vol-down|^volume\-|^vol_down|^volumedown|^RVolumeDown|^Volume_Minus|^Vol_Minus", \
         "vol+":"^vol\+|^volup|^vol-up|^volume\+|^vol_up|^volumeup|^RVolumeUp|^Volume_Plus|^Vol_Plus", \
         "mute":"^mute|^rmute|^gmute", \
         "chan-":"^chan\-|^chandown|^chan-down|^channel\-|^ch\-|^chdown|^ch_down|^channeldown|^chnldn|^channel_down|^tune\-|^RChannelDown|^Channel_Minus|^Chan_Minus|^PG_DN|^pg\-", \
         "chan+":"^chan\+|^chanup|^chan-up|^channel\+|^ch\+|^chup|^ch_up|^channelup|^chnlup|^channel_up|^tune\+|^RChannelUp|^Channel_Plus|^Chan_Plus|^PG_UP|^pg\+", \
-        "ok":"^ok|^start|^ent", \
+        "ok":"^ok|^start|^ent|^go|^select", \
         "home":"^home", \
-        "menu":"^menu|^rmenu|^gmenu", \
-        "info":"^info|^more|^osd|^display|^preview", \
+        "menu":"^menu|^rmenu|^gmenu|^dvdmenu", \
+        "info":"^info|^more|^osd|^display|^preview|^TaskSwitcher", \
         "pause":"^pause|^freeze|^playpause|^play-pause|^play_pause|^still", \
         "play":"^play|playpause|^play-pause|^play_pause", \
         "stop":"^stop|^esc|^cancel|^return", \
-        "exit":"^exit|^return|^close|^halt|^back/exit|^backexit", \
+        "exit":"^exit|^return|^close|^halt|^back/exit|^backexit|^back", \
         "record":"^record|^rec|^capture", \
         "one":"^1|^one|^r1|^G1", \
         "two":"^2|^two|^r2|^G2", \
@@ -61,12 +61,17 @@ class ProgramHandler():
         "zero":"^0|^zero|^r0|^G0", \
         "skip":"^skip", \
         "replay":"^replay", \
-        "guide":"^guide", \
+        "guide":"^guide|^AppLauncher", \
         "dvd":"^dvd|^dvd_vcd|^powerdvd|^power_dvd", \
         "red":"^red", \
         "green":"^green", \
         "yellow":"^yellow", \
-        "blue":"^blue" \
+        "blue":"^blue", \
+        "aspect":"^Zoom" , \
+        "fullscreen":"^FullScreen", \
+        "tuner":"^bookmarks", \
+        "delete":"^Hash", \
+        "subtitle":"^subtitle"
     }
 
     def __init__(self,application_name= None, application_dictionary=None,lircd="/etc/lirc/lircd.conf", lircrc=".lircrc", repeat="0", delay="0"):
@@ -112,17 +117,20 @@ class ProgramHandler():
                             list = string.split(line)
                             if len(list) >1 :
                                 remotename=list[1]
-                        if re.compile("begin codes").search(line) is not None:
+                        if re.compile("begin codes|begin raw_codes").search(line) is not None:
                             codes=True
-                            remotes[remotename]=[]
+                            if not remotes.has_key(remotename):
+                                remotes[remotename]=[]
                     else:
-                        if re.compile("end codes").search(line) is not None:
+                        if re.compile("end codes|end raw_codes").search(line) is not None:
                             codes=False
                         else:
                             list = string.split(line)
                             if len(list) > 1:
-                                #buttons[list[0]] = remotename
-                                remotes[remotename].append(list[0])
+                                if list[0] == "name":
+                                    remotes[remotename].append(list[1])
+                                else:
+                                    remotes[remotename].append(list[0])
             return remotes
         self.remotes = parse_lircd(self.lircd)
         out_f = open(self.lircrc,'a')
@@ -156,15 +164,15 @@ class ProgramHandler():
         #Go through all possible remotes
         #Remotes are represented as a dictionary item that matches a list
         for remote in self.remotes:
-            #Go through all possible buttons for this application
-            for item in self.application_dictionary:
-                pattern = re.compile(self.button_dictionary[item],re.IGNORECASE)
-                for button in self.remotes[remote]:
-                    if pattern.search(button) is not None:
+            for button in self.remotes[remote]:
+                key_split=button.split('KEY_')
+                for item in self.application_dictionary:
+                    pattern = re.compile(self.button_dictionary[item],re.IGNORECASE)
+                    if pattern.search(button) is not None or \
+                       (len(key_split) > 1 and pattern.search(key_split[1])):
                         self.write_key(stream,self.application_dictionary[item],button,remote)
                         break #we only want the first instance (ignore _DOWN or _UP)
 
-
     def write_key(self,stream,function,button,remote):
     	"""Writes a key block"""
     	stream.write("begin\n")
